routes.lru – LRU caching class and decorator — Routes v1.12 documentation

Routes

### Navigation

- index
- modules |
- next |
- previous |
- Routes home |
- Documentation»
- Routes Modules »

# `routes.lru` – LRU caching class and decorator

LRU caching class and decorator

## Module Contents

class `routes.lru.` `LRUCache`(size)
  Implements a psueudo-LRU algorithm (CLOCK)

### Navigation

- index
- modules |
- next |
- previous |
- Routes home |
- Documentation»
- Routes Modules »